@@ -1,5 +1,5 @@
 package Net::Stripe;
-$Net::Stripe::VERSION = '0.28';
+$Net::Stripe::VERSION = '0.30';
 use Moose;
 use Kavorka;
 use LWP::UserAgent;
@@ -65,22 +65,22 @@ Charges: {
         if (ref($charge)) {
             $charge = $charge->id;
         }
-        
+
         my $refund = Net::Stripe::Refund->new(id => $charge,
                                               amount => $amount
                                           );
         return $self->_post("charges/$charge/refunds", $refund);
     }
 
-    method get_charges(HashRef :$created?, 
+    method get_charges(HashRef :$created?,
                        Net::Stripe::Customer|Str :$customer?,
-                       Str :$ending_before?, 
-                       Int :$limit?, 
+                       Str :$ending_before?,
+                       Int :$limit?,
                        Str :$starting_after?) {
         if (ref($customer)) {
             $customer = $customer->id;
         }
-        $self->_get_collections('charges', 
+        $self->_get_collections('charges',
                                 created => $created,
                                 customer => $customer,
                                 ending_before => $ending_before,
@@ -108,16 +108,16 @@ Customers: {
                          Str :$coupon?,
                          Str :$default_card?,
                          Str :$description?,
-                         Str :$email?, 
-                         HashRef :$metadata?, 
-                         Str :$plan?, 
-                         Int :$quantity?, 
+                         Str :$email?,
+                         HashRef :$metadata?,
+                         Str :$plan?,
+                         Int :$quantity?,
                          Int|Str :$trial_end?) {
 
         if (defined($card) && ref($card) eq 'HASH') {
             $card = Net::Stripe::Card->new($card);
-        } 
-        
+        }
+
         if (ref($customer) eq 'Net::Stripe::Customer') {
             return $self->_post("customers/" . $customer->id, $customer);
         } elsif (defined($customer)) {
@@ -129,7 +129,7 @@ Customers: {
                 email => $email,
                 metadata => $metadata,
             );
-    
+
             return $self->_post("customers/" . $customer, _defined_arguments(\%args));
         }
 
@@ -146,14 +146,14 @@ Customers: {
         return $self->_post('customers', $customer);
     }
 
-    method list_subscriptions(Net::Stripe::Customer|Str :$customer, 
-                              Str :$ending_before?, 
-                              Int :$limit?, 
+    method list_subscriptions(Net::Stripe::Customer|Str :$customer,
+                              Str :$ending_before?,
+                              Int :$limit?,
                               Str :$starting_after?) {
         if (ref($customer)) {
             $customer = $customer->id;
         }
-        return $self->_get_collections("customers/$customer/subscriptions", 
+        return $self->_get_collections("customers/$customer/subscriptions",
                            ending_before => $ending_before,
                            limit => $limit,
                            starting_after => $starting_after
@@ -172,7 +172,7 @@ Customers: {
     }
 
     method get_customers(HashRef :$created?, Str :$ending_before?, Int :$limit?, Str :$starting_after?) {
-        $self->_get_collections('customers', 
+        $self->_get_collections('customers',
                                 created => $created,
                                 ending_before => $ending_before,
                                 limit => $limit,
@@ -183,7 +183,7 @@ Customers: {
 
 
 Cards: {
-    method get_card(Net::Stripe::Customer|Str :$customer, 
+    method get_card(Net::Stripe::Customer|Str :$customer,
                     Str :$card_id) {
         if (ref($customer)) {
             $customer = $customer->id;
@@ -192,15 +192,15 @@ Cards: {
     }
 
     method get_cards(Net::Stripe::Customer|Str $customer,
-                     HashRef :$created?, 
-                     Str :$ending_before?, 
-                     Int :$limit?, 
+                     HashRef :$created?,
+                     Str :$ending_before?,
+                     Int :$limit?,
                      Str :$starting_after?) {
         if (ref($customer)) {
             $customer = $customer->id;
         }
 
-        $self->_get_collections('cards', 
+        $self->_get_collections('cards',
                                 id => $customer,
                                 created => $created,
                                 ending_before => $ending_before,
@@ -208,7 +208,7 @@ Cards: {
                                 starting_after => $starting_after);
     }
 
-    method post_card(Net::Stripe::Customer|Str :$customer, 
+    method post_card(Net::Stripe::Customer|Str :$customer,
                      HashRef|Net::Stripe::Card :$card) {
         if (ref($customer)) {
             $customer = $customer->id;
@@ -250,7 +250,7 @@ Subscriptions: {
 
     # adds a subscription, keeping any existing subscriptions unmodified
     method post_subscription(Net::Stripe::Customer|Str :$customer,
-                             Net::Stripe::Subscription|Str :$subscription?, 
+                             Net::Stripe::Subscription|Str :$subscription?,
                              Net::Stripe::Plan|Str :$plan?,
                              Str :$coupon?,
                              Int|Str :$trial_end?,
@@ -280,10 +280,10 @@ Subscriptions: {
         } elsif (defined($subscription) && !ref($subscription)) {
             return $self->_post("customers/$customer/subscriptions/" . $subscription, _defined_arguments(\%args));
         }
-        
+
         return $self->_post("customers/$customer/subscriptions", _defined_arguments(\%args));
     }
-    
+
     method delete_subscription(Net::Stripe::Customer|Str :$customer,
                                Net::Stripe::Subscription|Str :$subscription,
                                Bool :$at_period_end?
@@ -348,7 +348,7 @@ Plans: {
     }
 
     method get_plans(Str :$ending_before?, Int :$limit?, Str :$starting_after?) {
-        $self->_get_collections('plans', 
+        $self->_get_collections('plans',
                                 ending_before => $ending_before,
                                 limit => $limit,
                                 starting_after => $starting_after);
@@ -390,7 +390,7 @@ Coupons: {
     }
 
     method get_coupons(Str :$ending_before?, Int :$limit?, Str :$starting_after?) {
-        $self->_get_collections('coupons', 
+        $self->_get_collections('coupons',
                                 ending_before => $ending_before,
                                 limit => $limit,
                                 starting_after => $starting_after);
@@ -419,12 +419,12 @@ Invoices: {
         if (ref($customer)) {
             $customer = $customer->id;
         }
-        
+
         if (ref($subscription)) {
             $subscription = $subscription->id;
         }
 
-        return $self->_post("invoices", 
+        return $self->_post("invoices",
                             {
                                 customer => $customer,
                                 application_fee => $application_fee,
@@ -444,7 +444,7 @@ Invoices: {
             $invoice = $invoice->id;
         }
 
-        return $self->_post("invoices/$invoice", 
+        return $self->_post("invoices/$invoice",
                             {
                                 application_fee => $application_fee,
                                 closed => $closed,
@@ -463,8 +463,8 @@ Invoices: {
 
     method get_invoices(Net::Stripe::Customer|Str :$customer?,
                         Int|HashRef :$date?,
-                        Str :$ending_before?, 
-                        Int :$limit?, 
+                        Str :$ending_before?,
+                        Int :$limit?,
                         Str :$starting_after?) {
         if (ref($customer)) {
             $customer = $customer->id
@@ -501,7 +501,7 @@ InvoiceItems: {
         if (ref($invoice)) {
             $invoice = $invoice->id;
         }
-        
+
         if (ref($subscription)) {
             $subscription = $subscription->id;
         }
@@ -530,7 +530,7 @@ InvoiceItems: {
             $invoice_item = $invoice_item->id;
         }
 
-        return $self->_post("invoiceitems/" . $invoice_item, 
+        return $self->_post("invoiceitems/" . $invoice_item,
                             {
                                 amount => $amount,
                                 description => $description,
@@ -551,13 +551,13 @@ InvoiceItems: {
 
     method get_invoiceitems(HashRef :$created?,
                             Net::Stripe::Customer|Str :$customer?,
-                            Str :$ending_before?, 
-                            Int :$limit?, 
+                            Str :$ending_before?,
+                            Int :$limit?,
                             Str :$starting_after?) {
         if (ref($customer)) {
             $customer = $customer->id;
         }
-        $self->_get_collections('invoiceitems', 
+        $self->_get_collections('invoiceitems',
                                 created => $created,
                                 ending_before => $ending_before,
                                 limit => $limit,
@@ -580,7 +580,7 @@ method _get_with_args(Str $path, $args?) {
     return $self->_get($path);
 }
 
-sub _get_collections { 
+sub _get_collections {
     my $self = shift;
     my $path = shift;
     my %args = @_;
@@ -594,15 +594,15 @@ sub _get_collections {
     if (my $c = $args{customer}) {
         push @path_args, "customer=$c";
     }
-    
+
     # example: $Stripe->get_charges( 'count' => 100, 'created' => { 'gte' => 1397663381 } );
     if (defined($args{created})) {
-      my %c = %{$args{created}};   
+      my %c = %{$args{created}};
       foreach my $key (keys %c) {
         if ($key =~ /(?:l|g)te?/) {
           push @path_args, "created[".$key."]=".$c{$key};
         }
-      }        
+      }
     }
     return $self->_get_with_args($path, \@path_args);
 }
@@ -632,13 +632,13 @@ sub convert_to_form_fields {
 }
 
 method _post(Str $path, $obj?) {
-    my $req = POST $self->api_base . '/' . $path, 
+    my $req = POST $self->api_base . '/' . $path,
         ($obj ? (Content => [ref($obj) eq 'HASH' ? %{convert_to_form_fields($obj)} : $obj->form_fields]) : ());
     return $self->_make_request($req);
 }
 
 method _make_request($req) {
-    $req->header( Authorization => 
+    $req->header( Authorization =>
         "Basic " . encode_base64($self->api_key . ':'));
 
     if ($self->debug_network) {
@@ -697,7 +697,7 @@ sub _hash_to_object {
 
     if (defined($hash->{object})) {
         if ($hash->{object} eq 'list') {
-            $hash->{data} = [map { _hash_to_object($_) } @{$hash->{data}}];        
+            $hash->{data} = [map { _hash_to_object($_) } @{$hash->{data}}];
             return Net::Stripe::List->new($hash);
         }
         my @words  = map { ucfirst($_) } split('_', $hash->{object});
@@ -730,7 +730,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.28
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -750,11 +750,11 @@ version 0.28
 
  # ... and the api mirrors https://stripe.com/docs/api
  # Charges: post_charge() get_charge() refund_charge() get_charges()
- # Customer: post_customer() 
+ # Customer: post_customer()
 
 =head1 DESCRIPTION
 
-This module is a wrapper around the Stripe.com HTTP API.  Methods are 
+This module is a wrapper around the Stripe.com HTTP API.  Methods are
 generally named after the HTTP method and the object name.
 
 This method returns Moose objects for responses from the API.
@@ -1099,7 +1099,7 @@ L<https://stripe.com/docs/api#list_cards>
 
 =over
 
-=item * customer - L<Net::Stripe::Customer> or Str 
+=item * customer - L<Net::Stripe::Customer> or Str
 
 =item * ending_before - Str, optional
 
@@ -1143,7 +1143,7 @@ L<https://stripe.com/docs/api#create_subscription>
 
 =item * customer - L<Net::Stripe::Customer>
 
-=item * subscription - L<Net::Stripe::Subscription> or Str 
+=item * subscription - L<Net::Stripe::Subscription> or Str
 
 =item * card - L<Net::Stripe::Card>, L<Net::Stripe::Token>, Str or HashRef, default card for the customer, optional
 
@@ -1189,9 +1189,9 @@ L<https://stripe.com/docs/api#cancel_subscription>
 
 =over
 
-=item * customer - L<Net::Stripe::Customer> or Str 
+=item * customer - L<Net::Stripe::Customer> or Str
 
-=item * subscription - L<Net::Stripe::Subscription> or Str 
+=item * subscription - L<Net::Stripe::Subscription> or Str
 
 =item * at_period_end - Bool, optional
 
@@ -1211,7 +1211,7 @@ L<https://stripe.com/docs/api#create_card_token>
 
 =over
 
-=item card - L<Net::Stripe::Card> or HashRef 
+=item card - L<Net::Stripe::Card> or HashRef
 
 =back
 
@@ -1419,7 +1419,7 @@ Update an invoice
 
 =over
 
-=item * invoice - L<Net::Stripe::Invoice>, Str 
+=item * invoice - L<Net::Stripe::Invoice>, Str
 
 =item * application_fee - Int - optional
 
@@ -1491,7 +1491,7 @@ L<https://stripe.com/docs/api#create_invoice>
 
 =over
 
-=item * customer - L<Net::Stripe::Customer>, Str 
+=item * customer - L<Net::Stripe::Customer>, Str
 
 =item * application_fee - Int - optional
 
@@ -1671,7 +1671,7 @@ Rusty Conover
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Solomon Sachin Sebastian Tom Eliaz Brian Collins Devin M. Certas Dimitar Petrov Dylan Reinhold Hermann Calabria Jonathan "Duke" Leto Luke Closs Olaf Alders Rusty Conover
+=for stopwords Andrew Solomon Brian Collins Devin M. Certas Dimitar Petrov Dylan Reinhold Hermann Calabria Jonathan "Duke" Leto Luke Closs Olaf Alders Paul Cochrane Rusty Conover Tom Eliaz
 
 =over 4
 
@@ -1681,14 +1681,6 @@ Andrew Solomon <andrew@illywhacker.net>
 
 =item *
 
-Sachin Sebastian <sachinjsk@users.noreply.github.com>
-
-=item *
-
-Tom Eliaz <tom@tomeliaz.com>
-
-=item *
-
 Brian Collins <bricollins@gmail.com>
 
 =item *
@@ -1721,8 +1713,16 @@ Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
+Paul Cochrane <paul@liekut.de>
+
+=item *
+
 Rusty Conover <rusty@luckydinosaur.com>
 
+=item *
+
+Tom Eliaz <tom@tomeliaz.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
