@@ -1,5 +1,7 @@
 package Net::Stripe::Resource;
-$Net::Stripe::Resource::VERSION = '0.28';
+$Net::Stripe::Resource::VERSION = '0.30';
+# ABSTRACT: represent a Resource object from Stripe
+
 use Moose;
 use Kavorka;
 
@@ -71,11 +73,11 @@ __END__
 
 =head1 NAME
 
-Net::Stripe::Resource
+Net::Stripe::Resource - represent a Resource object from Stripe
 
 =head1 VERSION
 
-version 0.28
+version 0.30
 
 =head1 AUTHORS
 
